@@ -21,6 +21,9 @@ import (
 	"fmt"
 	"testing"
 
+	fakeeventingclient "knative.dev/eventing/pkg/client/injection/client/fake"
+	fakedynamicclient "knative.dev/pkg/injection/clients/dynamicclient/fake"
+
 	"knative.dev/eventing/pkg/client/injection/reconciler/flows/v1alpha1/parallel"
 
 	corev1 "k8s.io/api/core/v1"
@@ -37,12 +40,12 @@ import (
 	duckv1alpha1 "knative.dev/pkg/apis/duck/v1alpha1"
 	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/controller"
+	"knative.dev/pkg/logging"
 	logtesting "knative.dev/pkg/logging/testing"
 	. "knative.dev/pkg/reconciler/testing"
 
 	"knative.dev/eventing/pkg/apis/flows/v1alpha1"
 	messagingv1beta1 "knative.dev/eventing/pkg/apis/messaging/v1beta1"
-	"knative.dev/eventing/pkg/reconciler"
 	"knative.dev/eventing/pkg/reconciler/parallel/resources"
 	. "knative.dev/eventing/pkg/reconciler/testing"
 	reconciletesting "knative.dev/eventing/pkg/reconciler/testing"
@@ -51,7 +54,6 @@ import (
 const (
 	testNS             = "test-namespace"
 	parallelName       = "test-parallel"
-	parallelUID        = "test-parallel-uid"
 	replyChannelName   = "reply-channel"
 	parallelGeneration = 79
 )
@@ -443,12 +445,15 @@ func TestAllBranches(t *testing.T) {
 	table.Test(t, MakeFactory(func(ctx context.Context, listers *Listers, cmw configmap.Watcher) controller.Reconciler {
 		ctx = channelable.WithDuck(ctx)
 		r := &Reconciler{
-			Base:               reconciler.NewBase(ctx, controllerAgentName, cmw),
 			parallelLister:     listers.GetFlowsParallelLister(),
 			channelableTracker: duck.NewListableTracker(ctx, channelable.Get, func(types.NamespacedName) {}, 0),
 			subscriptionLister: listers.GetSubscriptionLister(),
+			eventingClientSet:  fakeeventingclient.Get(ctx),
+			dynamicClientSet:   fakedynamicclient.Get(ctx),
 		}
-		return parallel.NewReconciler(ctx, r.Logger, r.EventingClientSet, listers.GetFlowsParallelLister(), r.Recorder, r)
+		return parallel.NewReconciler(ctx, logging.FromContext(ctx),
+			fakeeventingclient.Get(ctx), listers.GetFlowsParallelLister(),
+			controller.GetEventRecorder(ctx), r)
 	}, false, logger))
 }
 
